pub struct InputCollection { /* private fields */ }Expand description
Collection of many inputs
Implementations
Sourceimpl InputCollection
impl InputCollection
pub fn new() -> Self
Sourcepub fn add_input(&mut self, device: InputDevice)
pub fn add_input(&mut self, device: InputDevice)
Sourcepub fn get_input_arguments(&self, info: &Info) -> InputArguments
pub fn get_input_arguments(&self, info: &Info) -> InputArguments
Distribute all of the inputs in the collection amongst all of the players mentioned in the info argument and return a InputArgument suitable for passing to Game::Step()
Arguments
info- The game info