Module runtime

Module runtime 

This module contains code that is commonly needed by runtime implementations for various platforms, its not intended to be used for other purposes.

Structs

GameMutMap
A wrapper to convert a immutable Game to a mutable one
RunBundle
A structure for holding a game and its info struct together

Traits

GameMut
A version of the Game trait with mutable draw/render_audio. Some implementations need this.